==> haskell-prettyprinter-ansi-terminal-1.1.1.2-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-JbN1LsfCKYSGBixD84yusw
key: prettyprinter-ansi-terminal-1.1.1.2-JbN1LsfCKYSGBixD84yusw
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: 54cf17c06823b85c72a1c1f0718fca53
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-JbN1LsfCKYSGBixD84yusw
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    prettyprinter-1.3.0-8ZhWp3JcPbl4ZcQUS8pfN2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-4pSpq9ltOfi1hxNcyb7ifX
key: prettyprinter-ansi-terminal-1.1.1.2-4pSpq9ltOfi1hxNcyb7ifX
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: 3adee01df71cbad9a6b7e3ddeb273b05
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-4pSpq9ltOfi1hxNcyb7ifX
depends:
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X base-4.12.0.0
    prettyprinter-1.3.0-By2qerRheKP3pcx0TjvVGn text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
